@@ -1,4 +1,4 @@
-/* A Bison parser, made by GNU Bison 2.6.4.  */
+/* A Bison parser, made by GNU Bison 2.7.  */
 
 /* Bison interface for Yacc-like parsers in C
    
@@ -75,8 +75,8 @@ extern int i386_debug;
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
 {
-/* Line 2077 of yacc.c  */
-#line 217 "/home/mark/src/elfutils-clean/libcpu/i386_parse.y"
+/* Line 2058 of yacc.c  */
+#line 217 "i386_parse.y"
 
   unsigned long int num;
   char *str;
@@ -87,7 +87,7 @@ typedef union YYSTYPE
   struct argument *arg;
 
 
-/* Line 2077 of yacc.c  */
+/* Line 2058 of yacc.c  */
 #line 92 "i386_parse.h"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
