@@ -1,4 +1,4 @@
-/* A Bison parser, made by GNU Bison 2.6.4.  */
+/* A Bison parser, made by GNU Bison 2.7.  */
 
 /* Bison implementation for Yacc-like parsers in C
    
@@ -44,7 +44,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.6.4"
+#define YYBISON_VERSION "2.7"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -69,8 +69,8 @@
 #define yynerrs         ldnerrs
 
 /* Copy the first part of user declarations.  */
-/* Line 358 of yacc.c  */
-#line 1 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 371 of yacc.c  */
+#line 1 "ldscript.y"
 
 /* Parser for linker scripts.
    Copyright (C) 2001-2011 Red Hat, Inc.
@@ -132,7 +132,7 @@ static void add_versions (struct version *versions);
 
 extern int yylex (void);
 
-/* Line 358 of yacc.c  */
+/* Line 371 of yacc.c  */
 #line 137 "ldscript.c"
 
 # ifndef YY_NULL
@@ -232,8 +232,8 @@ extern int lddebug;
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
 {
-/* Line 374 of yacc.c  */
-#line 63 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 387 of yacc.c  */
+#line 63 "ldscript.y"
 
   uintmax_t num;
   enum expression_tag op;
@@ -249,7 +249,7 @@ typedef union YYSTYPE
   struct id_list *id_list;
 
 
-/* Line 374 of yacc.c  */
+/* Line 387 of yacc.c  */
 #line 254 "ldscript.c"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
@@ -277,7 +277,7 @@ int ldparse ();
 
 /* Copy the second part of user declarations.  */
 
-/* Line 377 of yacc.c  */
+/* Line 390 of yacc.c  */
 #line 282 "ldscript.c"
 
 #ifdef short
@@ -855,47 +855,18 @@ do                                                              \
     }								\
 while (YYID (0))
 
-
+/* Error token number */
 #define YYTERROR	1
 #define YYERRCODE	256
 
-/* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
-   If N is 0, then set CURRENT to the empty location which ends
-   the previous symbol: RHS[0] (always defined).  */
-
-#ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)                                \
-    do                                                                  \
-      if (YYID (N))                                                     \
-        {                                                               \
-          (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;        \
-          (Current).first_column = YYRHSLOC (Rhs, 1).first_column;      \
-          (Current).last_line    = YYRHSLOC (Rhs, N).last_line;         \
-          (Current).last_column  = YYRHSLOC (Rhs, N).last_column;       \
-        }                                                               \
-      else                                                              \
-        {                                                               \
-          (Current).first_line   = (Current).last_line   =              \
-            YYRHSLOC (Rhs, 0).last_line;                                \
-          (Current).first_column = (Current).last_column =              \
-            YYRHSLOC (Rhs, 0).last_column;                              \
-        }                                                               \
-    while (YYID (0))
-#endif
-
-#define YYRHSLOC(Rhs, K) ((Rhs)[K])
-
-
 
 /* This macro is provided for backward compatibility. */
-
 #ifndef YY_LOCATION_PRINT
 # define YY_LOCATION_PRINT(File, Loc) ((void) 0)
 #endif
 
 
 /* YYLEX -- calling `yylex' with the right arguments.  */
-
 #ifdef YYLEX_PARAM
 # define YYLEX yylex (YYLEX_PARAM)
 #else
@@ -958,7 +929,7 @@ yy_symbol_value_print (yyoutput, yytype, yyvaluep)
   switch (yytype)
     {
       default:
-	break;
+        break;
     }
 }
 
@@ -1200,7 +1171,6 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
 {
   YYSIZE_T yysize0 = yytnamerr (YY_NULL, yytname[yytoken]);
   YYSIZE_T yysize = yysize0;
-  YYSIZE_T yysize1;
   enum { YYERROR_VERBOSE_ARGS_MAXIMUM = 5 };
   /* Internationalized format string. */
   const char *yyformat = YY_NULL;
@@ -1263,11 +1233,13 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                     break;
                   }
                 yyarg[yycount++] = yytname[yyx];
-                yysize1 = yysize + yytnamerr (YY_NULL, yytname[yyx]);
-                if (! (yysize <= yysize1
-                       && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
-                  return 2;
-                yysize = yysize1;
+                {
+                  YYSIZE_T yysize1 = yysize + yytnamerr (YY_NULL, yytname[yyx]);
+                  if (! (yysize <= yysize1
+                         && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+                    return 2;
+                  yysize = yysize1;
+                }
               }
         }
     }
@@ -1287,10 +1259,12 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
 # undef YYCASE_
     }
 
-  yysize1 = yysize + yystrlen (yyformat);
-  if (! (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
-    return 2;
-  yysize = yysize1;
+  {
+    YYSIZE_T yysize1 = yysize + yystrlen (yyformat);
+    if (! (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+      return 2;
+    yysize = yysize1;
+  }
 
   if (*yymsg_alloc < yysize)
     {
@@ -1350,7 +1324,7 @@ yydestruct (yymsg, yytype, yyvaluep)
     {
 
       default:
-	break;
+        break;
     }
 }
 
@@ -1361,16 +1335,16 @@ yydestruct (yymsg, yytype, yyvaluep)
 int yychar;
 
 
-#ifndef YYLVAL_INITIALIZE
-# define YYLVAL_INITIALIZE()
-#endif
 #ifndef YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
 # define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
 # define YY_IGNORE_MAYBE_UNINITIALIZED_END
 #endif
+#ifndef YY_INITIAL_VALUE
+# define YY_INITIAL_VALUE(Value) /* Nothing. */
+#endif
 
 /* The semantic value of the lookahead symbol.  */
-YYSTYPE yylval;
+YYSTYPE yylval YY_INITIAL_VALUE(yyval_default);
 
 /* Number of syntax errors so far.  */
 int yynerrs;
@@ -1446,8 +1420,8 @@ yyparse ()
      Keep to zero when no symbol should be popped.  */
   int yylen = 0;
 
-  yyss = yyssa;
-  yyvs = yyvsa;
+  yyssp = yyss = yyssa;
+  yyvsp = yyvs = yyvsa;
   yystacksize = YYINITDEPTH;
 
   YYDPRINTF ((stderr, "Starting parse\n"));
@@ -1456,15 +1430,6 @@ yyparse ()
   yyerrstatus = 0;
   yynerrs = 0;
   yychar = YYEMPTY; /* Cause a token to be read.  */
-
-  /* Initialize stack pointers.
-     Waste one element of value and location stack
-     so that they stay on the same level as the state stack.
-     The wasted elements are never initialized.  */
-  yyssp = yyss;
-  yyvsp = yyvs;
-
-  YYLVAL_INITIALIZE ();
   goto yysetstate;
 
 /*------------------------------------------------------------.
@@ -1644,14 +1609,14 @@ yyreduce:
   switch (yyn)
     {
         case 3:
-/* Line 1813 of yacc.c  */
-#line 137 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 137 "ldscript.y"
     { add_versions ((yyvsp[(2) - (2)].version)); }
     break;
 
   case 6:
-/* Line 1813 of yacc.c  */
-#line 145 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 145 "ldscript.y"
     {
 		      if (likely (ld_state.entry == NULL))
 			ld_state.entry = (yyvsp[(3) - (5)].str);
@@ -1659,16 +1624,16 @@ yyreduce:
     break;
 
   case 7:
-/* Line 1813 of yacc.c  */
-#line 150 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 150 "ldscript.y"
     {
 		      ld_new_searchdir ((yyvsp[(3) - (5)].str));
 		    }
     break;
 
   case 8:
-/* Line 1813 of yacc.c  */
-#line 154 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 154 "ldscript.y"
     {
 		      if (likely (ld_state.pagesize == 0))
 			ld_state.pagesize = (yyvsp[(3) - (5)].num);
@@ -1676,8 +1641,8 @@ yyreduce:
     break;
 
   case 9:
-/* Line 1813 of yacc.c  */
-#line 159 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 159 "ldscript.y"
     {
 		      if (likely (ld_state.interp == NULL)
 			  && ld_state.file_type != dso_file_type)
@@ -1686,16 +1651,16 @@ yyreduce:
     break;
 
   case 10:
-/* Line 1813 of yacc.c  */
-#line 165 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 165 "ldscript.y"
     {
 		      new_segment ((yyvsp[(2) - (5)].num), (yyvsp[(4) - (5)].output_rule));
 		    }
     break;
 
   case 11:
-/* Line 1813 of yacc.c  */
-#line 169 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 169 "ldscript.y"
     {
 		      fputs_unlocked (gettext ("mode for segment invalid\n"),
 				      stderr);
@@ -1704,8 +1669,8 @@ yyreduce:
     break;
 
   case 12:
-/* Line 1813 of yacc.c  */
-#line 175 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 175 "ldscript.y"
     {
 		      /* First little optimization.  If there is only one
 			 file in the group don't do anything.  */
@@ -1719,32 +1684,32 @@ yyreduce:
     break;
 
   case 13:
-/* Line 1813 of yacc.c  */
-#line 186 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 186 "ldscript.y"
     { add_inputfiles ((yyvsp[(3) - (4)].filename_list)); }
     break;
 
   case 14:
-/* Line 1813 of yacc.c  */
-#line 188 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 188 "ldscript.y"
     { add_inputfiles (mark_as_needed ((yyvsp[(3) - (4)].filename_list))); }
     break;
 
   case 15:
-/* Line 1813 of yacc.c  */
-#line 190 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 190 "ldscript.y"
     { add_versions ((yyvsp[(3) - (4)].version)); }
     break;
 
   case 16:
-/* Line 1813 of yacc.c  */
-#line 192 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 192 "ldscript.y"
     { /* XXX TODO */ }
     break;
 
   case 17:
-/* Line 1813 of yacc.c  */
-#line 196 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 196 "ldscript.y"
     {
 		      (yyvsp[(2) - (2)].output_rule)->next = (yyvsp[(1) - (2)].output_rule)->next;
 		      (yyval.output_rule) = (yyvsp[(1) - (2)].output_rule)->next = (yyvsp[(2) - (2)].output_rule);
@@ -1752,14 +1717,14 @@ yyreduce:
     break;
 
   case 18:
-/* Line 1813 of yacc.c  */
-#line 201 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 201 "ldscript.y"
     { (yyval.output_rule) = (yyvsp[(1) - (1)].output_rule); }
     break;
 
   case 19:
-/* Line 1813 of yacc.c  */
-#line 205 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 205 "ldscript.y"
     {
 		      (yyval.output_rule) = new_output_rule (output_assignment);
 		      (yyval.output_rule)->val.assignment = (yyvsp[(1) - (2)].assignment);
@@ -1767,8 +1732,8 @@ yyreduce:
     break;
 
   case 20:
-/* Line 1813 of yacc.c  */
-#line 210 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 210 "ldscript.y"
     {
 		      (yyval.output_rule) = new_output_rule (output_section);
 		      (yyval.output_rule)->val.section.name = (yyvsp[(1) - (4)].str);
@@ -1783,8 +1748,8 @@ yyreduce:
     break;
 
   case 21:
-/* Line 1813 of yacc.c  */
-#line 222 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 222 "ldscript.y"
     {
 		      /* This is a short cut for "ID { *(ID) }".  */
 		      (yyval.output_rule) = new_output_rule (output_section);
@@ -1809,20 +1774,20 @@ yyreduce:
     break;
 
   case 22:
-/* Line 1813 of yacc.c  */
-#line 246 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 246 "ldscript.y"
     { (yyval.assignment) = new_assignment ((yyvsp[(1) - (3)].str), (yyvsp[(3) - (3)].expr), false); }
     break;
 
   case 23:
-/* Line 1813 of yacc.c  */
-#line 248 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 248 "ldscript.y"
     { (yyval.assignment) = new_assignment ((yyvsp[(3) - (6)].str), (yyvsp[(5) - (6)].expr), true); }
     break;
 
   case 24:
-/* Line 1813 of yacc.c  */
-#line 252 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 252 "ldscript.y"
     {
 		      (yyvsp[(2) - (2)].input_rule)->next = (yyvsp[(1) - (2)].input_rule)->next;
 		      (yyval.input_rule) = (yyvsp[(1) - (2)].input_rule)->next = (yyvsp[(2) - (2)].input_rule);
@@ -1830,14 +1795,14 @@ yyreduce:
     break;
 
   case 25:
-/* Line 1813 of yacc.c  */
-#line 257 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 257 "ldscript.y"
     { (yyval.input_rule) = (yyvsp[(1) - (1)].input_rule); }
     break;
 
   case 26:
-/* Line 1813 of yacc.c  */
-#line 261 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 261 "ldscript.y"
     {
 		      (yyval.input_rule) = new_input_rule (input_section);
 		      (yyval.input_rule)->val.section = (yyvsp[(1) - (1)].filemask_section_name);
@@ -1845,8 +1810,8 @@ yyreduce:
     break;
 
   case 27:
-/* Line 1813 of yacc.c  */
-#line 266 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 266 "ldscript.y"
     {
 		      (yyvsp[(3) - (4)].filemask_section_name)->keep_flag = true;
 
@@ -1856,8 +1821,8 @@ yyreduce:
     break;
 
   case 28:
-/* Line 1813 of yacc.c  */
-#line 273 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 273 "ldscript.y"
     {
 		      (yyval.input_rule) = new_input_rule (input_assignment);
 		      (yyval.input_rule)->val.assignment = (yyvsp[(1) - (2)].assignment);
@@ -1865,8 +1830,8 @@ yyreduce:
     break;
 
   case 29:
-/* Line 1813 of yacc.c  */
-#line 280 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 280 "ldscript.y"
     {
 		      (yyval.filemask_section_name) = (struct filemask_section_name *)
 			obstack_alloc (&ld_state.smem, sizeof (*(yyval.filemask_section_name)));
@@ -1878,32 +1843,32 @@ yyreduce:
     break;
 
   case 30:
-/* Line 1813 of yacc.c  */
-#line 291 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 291 "ldscript.y"
     { (yyval.sectionname) = new_input_section_name ((yyvsp[(1) - (1)].str), false); }
     break;
 
   case 31:
-/* Line 1813 of yacc.c  */
-#line 293 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 293 "ldscript.y"
     { (yyval.sectionname) = new_input_section_name ((yyvsp[(3) - (4)].str), true); }
     break;
 
   case 32:
-/* Line 1813 of yacc.c  */
-#line 297 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 297 "ldscript.y"
     { (yyval.str) = (yyvsp[(3) - (4)].str); }
     break;
 
   case 33:
-/* Line 1813 of yacc.c  */
-#line 299 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 299 "ldscript.y"
     { (yyval.str) = NULL; }
     break;
 
   case 34:
-/* Line 1813 of yacc.c  */
-#line 303 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 303 "ldscript.y"
     {
 		      (yyval.expr) = new_expr (exp_align);
 		      (yyval.expr)->val.child = (yyvsp[(3) - (4)].expr);
@@ -1911,14 +1876,14 @@ yyreduce:
     break;
 
   case 35:
-/* Line 1813 of yacc.c  */
-#line 308 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 308 "ldscript.y"
     { (yyval.expr) = (yyvsp[(2) - (3)].expr); }
     break;
 
   case 36:
-/* Line 1813 of yacc.c  */
-#line 310 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 310 "ldscript.y"
     {
 		      (yyval.expr) = new_expr (exp_mult);
 		      (yyval.expr)->val.binary.left = (yyvsp[(1) - (3)].expr);
@@ -1927,8 +1892,8 @@ yyreduce:
     break;
 
   case 37:
-/* Line 1813 of yacc.c  */
-#line 316 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 316 "ldscript.y"
     {
 		      (yyval.expr) = new_expr ((yyvsp[(2) - (3)].op));
 		      (yyval.expr)->val.binary.left = (yyvsp[(1) - (3)].expr);
@@ -1937,8 +1902,8 @@ yyreduce:
     break;
 
   case 38:
-/* Line 1813 of yacc.c  */
-#line 322 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 322 "ldscript.y"
     {
 		      (yyval.expr) = new_expr ((yyvsp[(2) - (3)].op));
 		      (yyval.expr)->val.binary.left = (yyvsp[(1) - (3)].expr);
@@ -1947,8 +1912,8 @@ yyreduce:
     break;
 
   case 39:
-/* Line 1813 of yacc.c  */
-#line 328 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 328 "ldscript.y"
     {
 		      (yyval.expr) = new_expr (exp_and);
 		      (yyval.expr)->val.binary.left = (yyvsp[(1) - (3)].expr);
@@ -1957,8 +1922,8 @@ yyreduce:
     break;
 
   case 40:
-/* Line 1813 of yacc.c  */
-#line 334 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 334 "ldscript.y"
     {
 		      (yyval.expr) = new_expr (exp_or);
 		      (yyval.expr)->val.binary.left = (yyvsp[(1) - (3)].expr);
@@ -1967,8 +1932,8 @@ yyreduce:
     break;
 
   case 41:
-/* Line 1813 of yacc.c  */
-#line 340 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 340 "ldscript.y"
     {
 		      (yyval.expr) = new_expr (exp_num);
 		      (yyval.expr)->val.num = (yyvsp[(1) - (1)].num);
@@ -1976,8 +1941,8 @@ yyreduce:
     break;
 
   case 42:
-/* Line 1813 of yacc.c  */
-#line 345 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 345 "ldscript.y"
     {
 		      (yyval.expr) = new_expr (exp_id);
 		      (yyval.expr)->val.str = (yyvsp[(1) - (1)].str);
@@ -1985,20 +1950,20 @@ yyreduce:
     break;
 
   case 43:
-/* Line 1813 of yacc.c  */
-#line 350 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 350 "ldscript.y"
     { (yyval.expr) = new_expr (exp_sizeof_headers); }
     break;
 
   case 44:
-/* Line 1813 of yacc.c  */
-#line 352 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 352 "ldscript.y"
     { (yyval.expr) = new_expr (exp_pagesize); }
     break;
 
   case 45:
-/* Line 1813 of yacc.c  */
-#line 356 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 356 "ldscript.y"
     {
 		      (yyvsp[(3) - (3)].filename_list)->next = (yyvsp[(1) - (3)].filename_list)->next;
 		      (yyval.filename_list) = (yyvsp[(1) - (3)].filename_list)->next = (yyvsp[(3) - (3)].filename_list);
@@ -2006,14 +1971,14 @@ yyreduce:
     break;
 
   case 46:
-/* Line 1813 of yacc.c  */
-#line 361 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 361 "ldscript.y"
     { (yyval.filename_list) = (yyvsp[(1) - (1)].filename_list); }
     break;
 
   case 49:
-/* Line 1813 of yacc.c  */
-#line 369 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 369 "ldscript.y"
     {
 		      /* First little optimization.  If there is only one
 			 file in the group don't do anything.  */
@@ -2027,20 +1992,20 @@ yyreduce:
     break;
 
   case 50:
-/* Line 1813 of yacc.c  */
-#line 380 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 380 "ldscript.y"
     { (yyval.filename_list) = mark_as_needed ((yyvsp[(3) - (4)].filename_list)); }
     break;
 
   case 51:
-/* Line 1813 of yacc.c  */
-#line 382 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 382 "ldscript.y"
     { (yyval.filename_list) = new_filename_listelem ((yyvsp[(1) - (1)].str)); }
     break;
 
   case 52:
-/* Line 1813 of yacc.c  */
-#line 387 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 387 "ldscript.y"
     {
 		      (yyvsp[(2) - (2)].version)->next = (yyvsp[(1) - (2)].version)->next;
 		      (yyval.version) = (yyvsp[(1) - (2)].version)->next = (yyvsp[(2) - (2)].version);
@@ -2048,14 +2013,14 @@ yyreduce:
     break;
 
   case 53:
-/* Line 1813 of yacc.c  */
-#line 392 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 392 "ldscript.y"
     { (yyval.version) = (yyvsp[(1) - (1)].version); }
     break;
 
   case 54:
-/* Line 1813 of yacc.c  */
-#line 396 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 396 "ldscript.y"
     {
 		      (yyvsp[(2) - (4)].version)->versionname = "";
 		      (yyvsp[(2) - (4)].version)->parentname = NULL;
@@ -2064,8 +2029,8 @@ yyreduce:
     break;
 
   case 55:
-/* Line 1813 of yacc.c  */
-#line 402 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 402 "ldscript.y"
     {
 		      (yyvsp[(3) - (5)].version)->versionname = (yyvsp[(1) - (5)].str);
 		      (yyvsp[(3) - (5)].version)->parentname = NULL;
@@ -2074,8 +2039,8 @@ yyreduce:
     break;
 
   case 56:
-/* Line 1813 of yacc.c  */
-#line 408 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 408 "ldscript.y"
     {
 		      (yyvsp[(3) - (6)].version)->versionname = (yyvsp[(1) - (6)].str);
 		      (yyvsp[(3) - (6)].version)->parentname = (yyvsp[(5) - (6)].str);
@@ -2084,32 +2049,32 @@ yyreduce:
     break;
 
   case 57:
-/* Line 1813 of yacc.c  */
-#line 417 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 417 "ldscript.y"
     { (yyval.version) = merge_versions ((yyvsp[(1) - (2)].version), (yyvsp[(2) - (2)].version)); }
     break;
 
   case 58:
-/* Line 1813 of yacc.c  */
-#line 419 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 419 "ldscript.y"
     { (yyval.version) = (yyvsp[(1) - (1)].version); }
     break;
 
   case 59:
-/* Line 1813 of yacc.c  */
-#line 423 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 423 "ldscript.y"
     { (yyval.version) = new_version (NULL, (yyvsp[(2) - (2)].id_list)); }
     break;
 
   case 60:
-/* Line 1813 of yacc.c  */
-#line 425 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 425 "ldscript.y"
     { (yyval.version) = new_version ((yyvsp[(2) - (2)].id_list), NULL); }
     break;
 
   case 61:
-/* Line 1813 of yacc.c  */
-#line 430 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 430 "ldscript.y"
     {
 		      struct id_list *newp = new_id_listelem ((yyvsp[(2) - (3)].str));
 		      newp->next = (yyvsp[(1) - (3)].id_list)->next;
@@ -2118,38 +2083,38 @@ yyreduce:
     break;
 
   case 62:
-/* Line 1813 of yacc.c  */
-#line 436 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 436 "ldscript.y"
     { (yyval.id_list) = new_id_listelem ((yyvsp[(1) - (2)].str)); }
     break;
 
   case 63:
-/* Line 1813 of yacc.c  */
-#line 440 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 440 "ldscript.y"
     { (yyval.str) = (yyvsp[(1) - (1)].str); }
     break;
 
   case 64:
-/* Line 1813 of yacc.c  */
-#line 442 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 442 "ldscript.y"
     { (yyval.str) = (yyvsp[(1) - (1)].str); }
     break;
 
   case 65:
-/* Line 1813 of yacc.c  */
-#line 446 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 446 "ldscript.y"
     { (yyval.str) = (yyvsp[(1) - (1)].str); }
     break;
 
   case 66:
-/* Line 1813 of yacc.c  */
-#line 448 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 1792 of yacc.c  */
+#line 448 "ldscript.y"
     { (yyval.str) = NULL; }
     break;
 
 
-/* Line 1813 of yacc.c  */
-#line 2153 "ldscript.c"
+/* Line 1792 of yacc.c  */
+#line 2118 "ldscript.c"
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -2380,8 +2345,8 @@ yyreturn:
 }
 
 
-/* Line 2076 of yacc.c  */
-#line 451 "/home/mark/src/elfutils-clean/src/ldscript.y"
+/* Line 2055 of yacc.c  */
+#line 451 "ldscript.y"
 
 
 static void
